--
-- Based on the following works:
-- https://github.com/MagicMau/ProceduralNameGenerator
-- https://github.com/Tw1ddle/MarkovNameGenerator
--

-- if os.getenv("LOCAL_LUA_DEBUGGER_VSCODE") == "1" then
--     require("lldebugger").start()
-- end
-- io.stdout:setvbuf("no")

local g = require("modules.generator")

math.randomseed(os.clock())

local trainingData = {}

for line in love.filesystem.lines("names.txt") do
	local name = string.lower(line)
	table.insert(trainingData, name)
end
print ('#trainingData', #trainingData)

-- Initialize the generator
-- @param1 trainingData A table of names to analyze
-- @param2 order Best described as a cohesion value
-- -- smaller = more random / unlikely / unpronounceable names
-- -- higher = names become similar/exact to training data
-- @param3 A Dirichlet prior is used to add a constant probability
-- -- that any letter may be picked as the next letter.
-- -- This acts as an additive smoothing factor and adds a bit more "randomness"
-- -- to the generated output.
local generator = g.new(trainingData, 3, 0.001)
local names = {}

local function generate2 ()
	local found = false

	-- Generate a name
	local x = string.gsub(generator:generate(), "#", "")

	-- Optional:
	-- reject names found in training data
	-- reject short names
	-- reject long names
	for _, value in pairs(trainingData) do
		if x == value or #x < 4 or #x > 12 then
			x = x:gsub("^%l", string.upper)
			found = true
			print (x)
			table.insert (names, 1, x)
			if #names > 30 then
				table.remove (names)
			end
			return false
		end
	end
	return true
end

function love.load()
    for count = 1, 30 do
		while  generate2 () do
			
		end
    end
	
	
end

function love.draw()
	love.graphics.print (#names, 0.5, 0)
	for i, name in ipairs (names) do
		love.graphics.print (string.format("%02d",#name)..'	'..name, 50.5, 20*(i-1))
	end
end


function love.keypressed(key, scancode, isrepeat)
	if key == "space" then
		for i = 1, 10 do
			while  generate2 () do
			
			end
		end
	elseif key == "escape" then
		love.event.quit()
	end
end
